package HTML::FormWidgets::Date;

# @(#)$Id: Date.pm 62 2008-06-29 09:30:34Z pjf $

use strict;
use warnings;
use base qw(HTML::FormWidgets);
use Readonly;

use version; our $VERSION = qv( sprintf '0.1.%d', q$Rev: 62 $ =~ /\d+/gmx );

Readonly my $TTS => q( ~ );

sub _render {
   my ($me, $ref) = @_; my ($format, $htag, $html, $text);

   $htag            = $me->elem;
   $ref->{size   }  = $me->width || 10;
   $format          = $me->format || q(dd/MM/yyyy);
   $text            = $htag->textfield( $ref );
   $html            = $htag->div( { class => q(container) }, $text );
   $html           .= $htag->div( { class => q(separator) }, q(&nbsp;) );
   $text            = 'function getAnchorPosition(anchorname) {';
   $text           .= 'var coordinates = new Object();';
	$text           .= 'coordinates.x = 0; coordinates.y = 0;';
	$text           .= 'return coordinates; }';
   $text           .= 'var '.$me->name."_cal = new CalendarPopup('";
   $text           .= $me->name."_calendar'); ";
   $text           .= $me->name."_cal.offsetX = 0; ";
   $text           .= $me->name."_cal.offsetY = 0; ";
   $html           .= $htag->script( { type => q(text/javascript) }, $text );
   $ref             = { alt => q(Calendar), class => q(icon) };
   $ref->{src    }  = $me->assets.'calendar.png';
   $text            = $htag->img( $ref );
   $ref             = {};
   $ref->{class  }  = q(tips);
   $ref->{href   }  = q();
   $ref->{id     }  = $me->name.'_anchor';
   $ref->{onclick}  = $me->name.'_cal.select( document.forms[0].'.$me->name;
   $ref->{onclick} .= ", '".$me->name."_anchor', '".$format."' ); ";
   $ref->{onclick} .= 'return false;';
   $ref->{title  }  = $me->hint_title.$TTS.$me->msg( q(dateWidgetTip) );
   $text            = $htag->a( $ref, $text );
   $text           .= $htag->div( { class => q(calendar hidden),
                                    id    => $me->name.'_calendar' } );
   $html           .= $htag->div( { class => q(container) }, $text );
   return $html;
}

1;

# Local Variables:
# mode: perl
# tab-width: 3
# End:

